google_api_knowledge_graph_search v0.2.0 GoogleApi.KnowledgeGraphSearch.V1.Model.SearchResponse View Source
Response message includes the context and a list of matching results which contain the detail of associated entities.
Attributes
- @context (any()): The local context applicable for the response. See more details at
http://www.w3.org/TR/json-ld/#context-definitions. Defaults to
nil. - @type (any()): The schema type of top-level JSON-LD object, e.g. ItemList. Defaults to
nil. - itemListElement (list(any())): The item list of search results. Defaults to
nil.
Link to this section Summary
Functions
Unwrap a decoded JSON object into its complex fields.
Link to this section Types
Link to this section Functions
Link to this function
decode(value, options) View Source
Unwrap a decoded JSON object into its complex fields.